# Generated by Django 3.2.5 on 2021-07-28 17:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_deep_link', '0003_auto_20210728_1622'),
    ]

    operations = [
        migrations.AlterField(
            model_name='app',
            name='android_package_name',
            field=models.CharField(blank=True, help_text='i.e. - com.company.appname. If blank, users will be redirected to the Default URL', max_length=255, verbose_name='Android Package Name'),
        ),
        migrations.AlterField(
            model_name='app',
            name='android_uri_scheme',
            field=models.CharField(blank=True, help_text='i.e. - myapp://', max_length=255, verbose_name='Android URI Scheme'),
        ),
        migrations.AlterField(
            model_name='app',
            name='ios_bundle_id',
            field=models.CharField(blank=True, help_text='i.e. - id1234567890', max_length=36, verbose_name='iOS Bundle ID'),
        ),
        migrations.AlterField(
            model_name='app',
            name='mac_uri_scheme',
            field=models.CharField(blank=True, help_text='i.e. - myapp://', max_length=255, verbose_name='Mac URI Scheme'),
        ),
        migrations.AlterField(
            model_name='app',
            name='windows_uri_scheme',
            field=models.CharField(blank=True, help_text='i.e. - myapp://', max_length=255, verbose_name='Windows URI Scheme'),
        ),
    ]
