# Generated by Django 3.2.5 on 2021-07-28 15:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_deep_link', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='app',
            name='mac_app',
            field=models.BooleanField(default=False, verbose_name='I have an Mac App'),
        ),
        migrations.AddField(
            model_name='app',
            name='windows_app',
            field=models.BooleanField(default=False, verbose_name='I have an Windows App'),
        ),
        migrations.AlterField(
            model_name='app',
            name='windows_package_name',
            field=models.CharField(blank=True, max_length=36, verbose_name='Windows Package Family Name'),
        ),
    ]
