# -*- coding: utf-8
from django.apps import AppConfig


class DjangoDeepLinkConfig(AppConfig):
    name = 'django_deep_link'
    verbose_name = 'Deep Link'
    default_auto_field = 'django.db.models.AutoField'
